.. romancal documentation master file
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:ref:`genindex`  |  :ref:`modindex`

===========
User Manual
===========

.. toctree::
   :maxdepth: 2

   roman/introduction.rst


=====================
Package Documentation
=====================

.. toctree::
   :maxdepth: 1

   roman/package_index.rst
